@@ -56,6 +56,7 @@ class Clean:
         Returns:
             typing.List[str]: The new list with the removed files
         """
+
         # Convert to array if string
         if isinstance(reserved, str):
             reserved = [reserved]
@@ -65,12 +66,22 @@ class Clean:
             return data
 
         newData = []
-        for item in reserved:
-            if item.startswith("*"):
-                for file in data:
-                    if not file.endswith(item[1:]) and file not in reserved:
-                        newData.append(file)
+        for file in data:
+            # Reserved check
+            if file in reserved:
+                continue
 
+            # ends with reserved *
+            endswithForbidden = False
+            for item in reserved:
+                if item.startswith("*"):
+                    if file.endswith(item[1:]):
+                        endswithForbidden = True
+
+            if endswithForbidden:
+                continue
+
+            newData.append(file)
         return newData
 
     def clean(self, path: str, reserved: typing.List[str] = None) -> typing.List[str]:
